@@ -1,4 +1,4 @@
-#' Equality test for the unknown components of admixture models
+#' Equality test for the unknown components in admixture models
 #'
 #' Perform hypothesis test between unknown components of a list of admixture models, where we remind that the i-th admixture
 #' model has probability density function (pdf) l_i such that:
@@ -16,7 +16,7 @@
 #'                    only 'poly' is available and the test is a gaussianity test. For further details, see section 'Details' below.
 #' @param conf_level The confidence level of the K-sample test.
 #' @param ... Depending on the choice made by the user for the test method ('poly' or 'icv'), optional arguments to
-#'            \link[admix]{gaussianity_test} or \link[admix]{orthobasis_test} (in case of 'poly'), and to \link[admix]{IBM_k_samples_test}
+#'            \link[admix]{gaussianity_test}, \link[admix]{orthobasis_test} (in case of 'poly'), or \link[admix]{IBM_k_samples_test}
 #'            in case of 'icv'.
 #'
 #' @details For further details on implemented hypothesis tests, see the references hereafter.
@@ -26,10 +26,11 @@
 #' \insertRef{MilhaudPommeretSalhiVandekerkhove2022}{admix}
 #' \insertRef{PommeretVandekerkhove2019}{admix}
 #'
-#' @return An object of class 'htest' containing the classical attributes of the latter class, as well as
-#'         other attributes specific to the inherited object class. Usually, the test decision (reject the null hypothesis or not);
-#'         the confidence level of the test (1-alpha, where alpha denotes the level of the test or equivalently the type-I error);
-#'         the number of samples under study; the respective size of each sample; the information about known mixture components.
+#' @return An object of class \code{gaussianity_test}, \code{orthobasis_test}, or \code{IBM_test} (that inherits from
+#'         class \code{htest}), containing attributes specific to the object class (in addition to classical attributes
+#'         from \code{htest}). Usually, the test decision (reject the null hypothesis or not); the confidence level of
+#'         the test (1-alpha, where alpha denotes the level of the test or equivalently the type-I error); the number
+#'         of samples under study; the respective size of each sample; the information about known mixture components.
 #'
 #' @examples
 #' ####### Example with 2 samples
@@ -55,8 +56,8 @@
 
 admix_test <- function(samples, admixMod, test_method = c("poly","icv"), conf_level = 0.95, ...)
 {
-  if (!is.list(samples))
-    stop("Please provide sample(s) and admixture model(s) in a list, also with only one sample!")
+  if (!is.list(samples) | !is.list(admixMod))
+    stop("Please provide sample(s) AND admixture model(s) in a list, also with only one sample!")
   if (!all(sapply(X = admixMod, FUN = inherits, what = "admix_model")))
     stop("Argument 'admixMod' is not correctly specified. See ?admix_model.")
 
@@ -64,17 +65,11 @@ admix_test <- function(samples, admixMod, test_method = c("poly","icv"), conf_le
   n_samples <- length(samples)
 
   ## Check right specification of arguments:
-  if ((n_samples > 2) & (meth == "poly")) stop("Testing using polynomial basis expansions involves at most TWO samples.\n")
-  if ((n_samples == 1) & (meth == "icv")) stop("Testing using the inner convergence property (obtained from IBM estimation) requires at least TWO samples.\n")
-  if (meth == "poly") message("  Testing using polynomial basis expansions requires in theory a square-root n consistent estimation
-  of the proportions of the unknown component distributions (thus using 'BVdk' estimation by default,
-  associated to unknown component distributions with symmetric densities). However, for practical
-  considerations, it is allowed to use 'PS' estimator in the 2-sample case (argument 'est_method' has
-  therefore to be set to 'PS'). In this case, the variance of estimators is obtained by boostrapping.\n")
-
-  old_options_warn <- base::options()$warn
-  on.exit(base::options(warn = old_options_warn))
-  base::options(warn = -1)
+  if ((n_samples > 2) & (meth == "poly")) stop("Testing using polynomial basis expansions ('poly') involves at most TWO samples.\n")
+  if ((n_samples == 1) & (meth == "icv")) stop("Testing using the Inner ConVergence property ('icv') requires at least TWO samples.\n")
+  if (meth == "poly") message("  Default estimation method is 'BVdk' when testing with polynomial basis expansions (ensuring
+  theoretical guarantees, but relying on symmetric unknown component densities). To consider
+  other frameworks in the 2-sample case, use 'PS' estimator (setting argument 'est_method' to 'PS').")
 
   if (meth == "icv") {
     if (n_samples >= 2) {
