@@ -17,8 +17,6 @@ admixStartupMessage <- function()
 
 .onAttach <- function(lib, pkg)
 {
-  # unlock .admix variable allowing its modification
-  #unlockBinding(".admix", asNamespace("admix"))
   # startup message
   msg <- admixStartupMessage()
   if(!interactive())
@@ -27,6 +25,105 @@ admixStartupMessage <- function()
   base::invisible()
 }
 
+
+.onLoad <- function(libname, pkgname) {
+  ns <- asNamespace(pkgname)
+  # si les fonctions méthodes existent dans le namespace, enregistre-les
+  if (exists("get_mixture_data.twoComp_mixt", envir = ns, inherits = FALSE)) {
+    registerS3method("get_mixture_data", "twoComp_mixt",
+                     get("get_mixture_data.twoComp_mixt", envir = ns), envir = ns)
+  }
+  if (exists("get_known_component.admix_estim", envir = ns, inherits = FALSE)) {
+    registerS3method("get_known_component", "admix_estim",
+                     get("get_known_component.admix_estim", envir = ns), envir = ns)
+  }
+  if (exists("get_known_component.gaussianity_test", envir = ns, inherits = FALSE)) {
+    registerS3method("get_known_component", "gaussianity_test",
+                     get("get_known_component.gaussianity_test", envir = ns), envir = ns)
+  }
+  if (exists("get_known_component.orthobasis_test", envir = ns, inherits = FALSE)) {
+    registerS3method("get_known_component", "orthobasis_test",
+                     get("get_known_component.orthobasis_test", envir = ns), envir = ns)
+  }
+  if (exists("get_known_component.IBM_test", envir = ns, inherits = FALSE)) {
+    registerS3method("get_known_component", "IBM_test",
+                     get("get_known_component.IBM_test", envir = ns), envir = ns)
+  }
+  if (exists("get_known_component.admix_cluster", envir = ns, inherits = FALSE)) {
+    registerS3method("get_known_component", "admix_cluster",
+                     get("get_known_component.admix_cluster", envir = ns), envir = ns)
+  }
+  if (exists("get_mixing_weights.admix_estim", envir = ns, inherits = FALSE)) {
+    registerS3method("get_mixing_weights", "admix_estim",
+                     get("get_mixing_weights.admix_estim", envir = ns), envir = ns)
+  }
+  if (exists("get_mixing_weights.gaussianity_test", envir = ns, inherits = FALSE)) {
+    registerS3method("get_mixing_weights", "gaussianity_test",
+                     get("get_mixing_weights.gaussianity_test", envir = ns), envir = ns)
+  }
+  if (exists("get_mixing_weights.orthobasis_test", envir = ns, inherits = FALSE)) {
+    registerS3method("get_mixing_weights", "orthobasis_test",
+                     get("get_mixing_weights.orthobasis_test", envir = ns), envir = ns)
+  }
+  if (exists("reject_nullHyp.gaussianity_test", envir = ns, inherits = FALSE)) {
+    registerS3method("reject_nullHyp", "gaussianity_test",
+                     get("reject_nullHyp.gaussianity_test", envir = ns), envir = ns)
+  }
+  if (exists("reject_nullHyp.orthobasis_test", envir = ns, inherits = FALSE)) {
+    registerS3method("reject_nullHyp", "orthobasis_test",
+                     get("reject_nullHyp.orthobasis_test", envir = ns), envir = ns)
+  }
+  if (exists("reject_nullHyp.IBM_test", envir = ns, inherits = FALSE)) {
+    registerS3method("reject_nullHyp", "IBM_test",
+                     get("reject_nullHyp.IBM_test", envir = ns), envir = ns)
+  }
+  if (exists("which_rank.gaussianity_test", envir = ns, inherits = FALSE)) {
+    registerS3method("which_rank", "gaussianity_test",
+                     get("which_rank.gaussianity_test", envir = ns), envir = ns)
+  }
+  if (exists("which_rank.orthobasis_test", envir = ns, inherits = FALSE)) {
+    registerS3method("which_rank", "orthobasis_test",
+                     get("which_rank.orthobasis_test", envir = ns), envir = ns)
+  }
+  if (exists("which_rank.IBM_test", envir = ns, inherits = FALSE)) {
+    registerS3method("which_rank", "IBM_test",
+                     get("which_rank.IBM_test", envir = ns), envir = ns)
+  }
+  if (exists("get_tabulated_dist.IBM_test", envir = ns, inherits = FALSE)) {
+    registerS3method("get_tabulated_dist", "IBM_test",
+                     get("get_tabulated_dist.IBM_test", envir = ns), envir = ns)
+  }
+  if (exists("get_tabulated_dist.admix_cluster", envir = ns, inherits = FALSE)) {
+    registerS3method("get_tabulated_dist", "admix_cluster",
+                     get("get_tabulated_dist.admix_cluster", envir = ns), envir = ns)
+  }
+  if (exists("get_discrepancy_rank.IBM_test", envir = ns, inherits = FALSE)) {
+    registerS3method("get_discrepancy_rank", "IBM_test",
+                     get("get_discrepancy_rank.IBM_test", envir = ns), envir = ns)
+  }
+  if (exists("get_discrepancy_matrix.IBM_test", envir = ns, inherits = FALSE)) {
+    registerS3method("get_discrepancy_matrix", "IBM_test",
+                     get("get_discrepancy_matrix.IBM_test", envir = ns), envir = ns)
+  }
+  if (exists("get_discrepancy_matrix.admix_cluster", envir = ns, inherits = FALSE)) {
+    registerS3method("get_discrepancy_matrix", "admix_cluster",
+                     get("get_discrepancy_matrix.admix_cluster", envir = ns), envir = ns)
+  }
+  if (exists("get_statistic_components.IBM_test", envir = ns, inherits = FALSE)) {
+    registerS3method("get_statistic_components", "IBM_test",
+                     get("get_statistic_components.IBM_test", envir = ns), envir = ns)
+  }
+  if (exists("get_cluster_members.admix_cluster", envir = ns, inherits = FALSE)) {
+    registerS3method("get_cluster_members", "admix_cluster",
+                     get("get_cluster_members.admix_cluster", envir = ns), envir = ns)
+  }
+  if (exists("get_cluster_sizes.admix_cluster", envir = ns, inherits = FALSE)) {
+    registerS3method("get_cluster_sizes", "admix_cluster",
+                     get("get_cluster_sizes.admix_cluster", envir = ns), envir = ns)
+  }
+}
+
+
 #' Detect the type of support of some random variables
 #'
 #' Given one or two sets of observations (samples), the function provides with the most plausible type of support for the
@@ -125,8 +222,8 @@ sim_gaussianProcess <- function(mean_vec, varCov_mat, from = 0, to = 1, start =
 #'
 #' Test if the known component distributions coming from two admixture models are identical.
 #'
-#' @param admixMod1 An object of class 'admix_model' related to the first admixture model.
-#' @param admixMod2 An object of class 'admix_model' related to the second admixture model.
+#' @param admixMod1 An object of class \code{admix_model} related to the first admixture model.
+#' @param admixMod2 An object of class \code{admix_model} related to the second admixture model.
 #'
 #' @return A boolean (TRUE if the known components are the same, otherwise FALSE).
 #'
@@ -211,7 +308,7 @@ kernel_density <- function(u, h)
 #' Useful when dealing with the Patra and Sen estimator (for the estimation of the unknown weight p).
 #'
 #' @param data Observations of the sample under study, following an admixture distribution.
-#' @param admixMod An object of class 'admix_model', containing useful information about the known components and their parameter(s).
+#' @param admixMod An object of class \code{admix_model}, containing useful information about the known components and their parameter(s).
 #'
 #' @return The transformed data, i.e. the transformed mixture distribution where the known component g now follows a
 #'         Uniform(0,1) distribution.
